<?php

namespace Drupal\pf_onesignal\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure Push Framework OneSignal settings for this site.
 */
class Settings extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'pf_onesignal_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames(): array {
    return ['pf_onesignal.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    $config = $this->config('pf_onesignal.settings');
    $form['active'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Active'),
      '#default_value' => $config->get('active'),
    ];
    $form['appid'] = [
      '#type' => 'textfield',
      '#title' => $this->t('AppId'),
      '#default_value' => $config->get('appid'),
    ];
    $form['authkey'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Auth key'),
      '#default_value' => $config->get('authkey'),
    ];
    $form['mobilebundleid'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Mobild bundle ID'),
      '#default_value' => $config->get('mobilebundleid'),
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    $this->config('pf_onesignal.settings')
      ->set('active', $form_state->getValue('active'))
      ->set('appid', $form_state->getValue('appid'))
      ->set('authkey', $form_state->getValue('authkey'))
      ->set('mobilebundleid', $form_state->getValue('mobilebundleid'))
      ->save();
    parent::submitForm($form, $form_state);
  }

}
